@@ -1,9 +1,12 @@
 """rope, a python refactoring library"""
 
+from pkg_resources import get_distribution
+
+
 INFO = __doc__
-VERSION = "0.23.0"
+VERSION = get_distribution("rope").version
 COPYRIGHT = """\
-Copyright (C) 2021-2021 Lie Ryan
+Copyright (C) 2021-2022 Lie Ryan
 Copyright (C) 2019-2021 Matej Cepl
 Copyright (C) 2015-2018 Nicholas Smith
 Copyright (C) 2014-2015 Matej Cepl
